Utils for working with the HTML message style.
Functions
- blockquote
- Applies the block quotation style to the string.
- bold
- Applies the bold font style to the string.
- code_
block - Formats the code block.
- code_
block_ with_ lang - Formats the code block with a specific language syntax.
- code_
inline - Formats the string as an inline code.
- escape
- Escapes the string to be shown “as is” within the Telegram HTML message style.
- italic
- Applies the italic font style to the string.
- link
- Builds an inline link with an anchor.
- strike
- Applies the strikethrough font style to the string.
- underline
- Applies the underline font style to the string.
- user_
mention - Builds an inline user mention link with an anchor.
- user_
mention_ or_ link